@@ -1,6 +1,6 @@
 package CatalystX::DebugFilter;
 BEGIN {
-  $CatalystX::DebugFilter::VERSION = '0.08';
+  $CatalystX::DebugFilter::VERSION = '0.09';
 }
 
 # ABSTRACT: Provides configurable filtering of data that is logged to the debug logs (and error screen)
@@ -13,6 +13,7 @@ my %filters = (
     Request  => \&_filter_request,
     Response => \&_filter_response,
     Stash    => \&_filter_stash,
+    Session  => \&_filter_session,
 );
 around dump_these => sub {
     my $next = shift;
@@ -158,6 +159,12 @@ sub _filter_stash {
     return _filter_hash_ref($stash);
 }
 
+sub _filter_session {
+    my ( $config, $stash ) = @_;
+    my @filters = _normalize_filters($config);
+    return _filter_hash_ref($stash);
+}
+
 1;
 
 
@@ -170,7 +177,7 @@ CatalystX::DebugFilter - Provides configurable filtering of data that is logged
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -204,14 +211,17 @@ version 0.08
                         return undef;
                     }
                 },
-            ]
+            ],
+            Session => [
+                'secret_session_key'
+            ],
         }
     );
 
 =head1 DESCRIPTION
 
 This module provides a Moose role that will filter certain elements of
-a request/response/stash before they are logged to the debug logs (or
+a request/response/stash/session before they are logged to the debug logs (or
 the error screen).
 
 =head1 METHODS
@@ -296,10 +306,10 @@ prevent passwords from being logged to the debug logs but if you create
 an object that contains that password and store it in the stash, the
 password value may still appear on the error screen.
 
-Also, the stash is only filtered at the top level.  If you would like to
-filter more extensively, you can use a filter callback to traverse the
-stash, modifying whatever data you like (a copy is made before passing
-the value to the callback).
+Also, the stash and session are only filtered at the top level.  If you
+would like to filter more extensively, you can use a filter callback to
+traverse the hash, modifying whatever data you like (a shallow copy is
+made before passing the value to the callback).
 
 =head1 SEE ALSO
 
